@@ -76,6 +76,7 @@ STRUCTURE = Nav(
                 Nav("Grégoire « Koraysh »", cat="invite"),
                 Nav("Louis « Imperia86 »", cat="habitue"),
                 Nav("Martin « Spigushe »", cat="habitue"),
+                Nav("Nicolas « NicolasP »", cat="invite"),
                 Nav("Apparitions", cat="invite"),
             ],
         ),
@@ -142,38 +143,39 @@ STRUCTURE = Nav(
             "⏯️ Matchs",
             index=True,
             children=[
-                Nav("1. Adeliz vs Kinnan", cat="01-10"),
-                Nav("2. Kari Zev vs Saskia", cat="01-10"),
-                Nav("3. Isamaru vs Gitrog", cat="01-10"),
-                Nav("4. Livio-Malcolm vs Niv 5C", cat="01-10"),
-                Nav("5. Jori En vs Sygg", cat="01-10"),
-                Nav("6. Aminatou vs Klothys", cat="01-10"),
-                Nav("7. Livio-Prava vs Ojutai", cat="01-10"),
-                Nav("8. Esika vs Niv 5C", cat="01-10"),
-                Nav("9. Miara-Tevesh vs Prossh", cat="01-10"),
-                Nav("10. Kari Zev vs Marath", cat="01-10"),
-                Nav("11. Doran vs Marchesa", cat="11-20"),
-                Nav("12. Light Paws vs Ishai-Tevesh", cat="11-20"),
-                Nav("13. Bjorna-Wernog vs Grist", cat="11-20"),
-                Nav("14. Minsc vs ❌ Shorikai", cat="11-20"),
-                Nav("15. Dennick vs Hinata", cat="11-20"),
-                Nav("16. Aminatou vs Tiamat", cat="11-20"),
-                Nav("17. Grist vs Sythis", cat="11-20"),
-                Nav("18. Kari Zev vs Killian [Budget]", cat="11-20"),
-                Nav("19. Elmar-Sophina vs ❌ Shorikai", cat="11-20"),
-                Nav("20. Juri vs Sai", cat="11-20"),
-                Nav("21. Aminatou vs Beamtown", cat="21-30"),
-                Nav("22. Raffine vs Tivit", cat="21-30"),
-                Nav("23. Karlov vs Reality Chip", cat="21-30"),
-                Nav("24. Grist vs ❌ Minsc&Boo", cat="21-30"),
-                Nav("25. Elminster vs Wilson", cat="21-30"),
-                Nav("26. Hogaak vs ❌ Minsc&Boo", cat="21-30"),
-                Nav("27. Jori En vs Maelstrom Wanderer", cat="21-30"),
-                Nav("28. Azusa vs Elmar-Hargilde", cat="21-30"),
-                Nav("29. Erinis vs Raff", cat="21-30"),
-                Nav("30. Gut vs Yoshimaru", cat="21-30"),
-                Nav("31. Raffine vs Soul of Windgrace", cat="31-40"),
-                Nav("32. Grenzo vs Shanna", cat="31-40"),
+                Nav("1. Adeliz vs Kinnan", cat="match"),
+                Nav("2. Kari Zev vs Saskia", cat="match"),
+                Nav("3. Isamaru vs Gitrog", cat="match"),
+                Nav("4. Livio-Malcolm vs Niv 5C", cat="match"),
+                Nav("5. Jori En vs Sygg", cat="match"),
+                Nav("6. Aminatou vs Klothys", cat="match"),
+                Nav("7. Livio-Prava vs Ojutai", cat="match"),
+                Nav("8. Esika vs Niv 5C", cat="match"),
+                Nav("9. Miara-Tevesh vs Prossh", cat="match"),
+                Nav("10. Kari Zev vs Marath", cat="match"),
+                Nav("11. Doran vs Marchesa", cat="match"),
+                Nav("12. Light Paws vs Ishai-Tevesh", cat="match"),
+                Nav("13. Bjorna-Wernog vs Grist", cat="match"),
+                Nav("14. Minsc vs ❌ Shorikai", cat="match"),
+                Nav("15. Dennick vs Hinata", cat="match"),
+                Nav("16. Aminatou vs Tiamat", cat="match"),
+                Nav("17. Grist vs Sythis", cat="match"),
+                Nav("18. Kari Zev vs Killian [Budget]", cat="match"),
+                Nav("19. Elmar-Sophina vs ❌ Shorikai", cat="match"),
+                Nav("20. Juri vs Sai", cat="match"),
+                Nav("21. Aminatou vs Beamtown", cat="match"),
+                Nav("22. Raffine vs Tivit", cat="match"),
+                Nav("23. Karlov vs Reality Chip", cat="match"),
+                Nav("24. Grist vs ❌ Minsc&Boo", cat="match"),
+                Nav("25. Elminster vs Wilson", cat="match"),
+                Nav("26. Hogaak vs ❌ Minsc&Boo", cat="match"),
+                Nav("27. Jori En vs Maelstrom Wanderer", cat="match"),
+                Nav("28. Azusa vs Elmar-Hargilde", cat="match"),
+                Nav("29. Erinis vs Raff", cat="match"),
+                Nav("30. Gut vs Yoshimaru", cat="match"),
+                Nav("31. Raffine vs Soul of Windgrace", cat="match"),
+                Nav("32. Grenzo vs Shanna", cat="match"),
+                Nav("33. Juri vs Wilson", cat="match"),
             ],
         ),
         Nav(
